Rename Lambda in org.onosproject.net.resource to LambdaResource

To avoid naming conflict with Lambda in org.onosproject.net

Change-Id: Ic8a670e7e2fb022f44f5a83cf4805f3ce0f29694
diff --git a/core/api/src/main/java/org/onosproject/net/intent/constraint/LambdaConstraint.java b/core/api/src/main/java/org/onosproject/net/intent/constraint/LambdaConstraint.java
index dfca98b..f9bf42e 100644
--- a/core/api/src/main/java/org/onosproject/net/intent/constraint/LambdaConstraint.java
+++ b/core/api/src/main/java/org/onosproject/net/intent/constraint/LambdaConstraint.java
@@ -16,7 +16,7 @@
 package org.onosproject.net.intent.constraint;
 
 import org.onosproject.net.Link;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LinkResourceService;
 import org.onosproject.net.resource.ResourceRequest;
 import org.onosproject.net.resource.ResourceType;
@@ -30,14 +30,14 @@
  */
 public class LambdaConstraint extends BooleanConstraint {
 
-    private final Lambda lambda;
+    private final LambdaResource lambda;
 
     /**
      * Creates a new optical lambda constraint.
      *
      * @param lambda optional lambda to indicate a specific lambda
      */
-    public LambdaConstraint(Lambda lambda) {
+    public LambdaConstraint(LambdaResource lambda) {
         this.lambda = lambda;
     }
 
@@ -61,7 +61,7 @@
      *
      * @return required lambda
      */
-    public Lambda lambda() {
+    public LambdaResource lambda() {
         return lambda;
     }
 
diff --git a/core/api/src/main/java/org/onosproject/net/resource/LambdaResourceAllocation.java b/core/api/src/main/java/org/onosproject/net/resource/LambdaResourceAllocation.java
index e564059..e34dab5 100644
--- a/core/api/src/main/java/org/onosproject/net/resource/LambdaResourceAllocation.java
+++ b/core/api/src/main/java/org/onosproject/net/resource/LambdaResourceAllocation.java
@@ -24,7 +24,7 @@
  */
 public class LambdaResourceAllocation extends LambdaResourceRequest
         implements ResourceAllocation {
-    private final Lambda lambda;
+    private final LambdaResource lambda;
 
     @Override
     public ResourceType type() {
@@ -32,12 +32,12 @@
     }
 
     /**
-     * Creates a new {@link LambdaResourceAllocation} with {@link Lambda}
+     * Creates a new {@link LambdaResourceAllocation} with {@link LambdaResource}
      * object.
      *
      * @param lambda allocated lambda
      */
-    public LambdaResourceAllocation(Lambda lambda) {
+    public LambdaResourceAllocation(LambdaResource lambda) {
         this.lambda = lambda;
     }
 
@@ -46,7 +46,7 @@
      *
      * @return the lambda resource
      */
-    public Lambda lambda() {
+    public LambdaResource lambda() {
         return lambda;
     }
 
diff --git a/core/api/src/test/java/org/onosproject/net/intent/IntentTestsMocks.java b/core/api/src/test/java/org/onosproject/net/intent/IntentTestsMocks.java
index 8e89632..279a8bb 100644
--- a/core/api/src/test/java/org/onosproject/net/intent/IntentTestsMocks.java
+++ b/core/api/src/test/java/org/onosproject/net/intent/IntentTestsMocks.java
@@ -37,7 +37,7 @@
 import org.onosproject.net.flow.instructions.Instructions;
 import org.onosproject.net.resource.Bandwidth;
 import org.onosproject.net.resource.BandwidthResourceRequest;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LambdaResourceRequest;
 import org.onosproject.net.resource.LinkResourceAllocations;
@@ -179,7 +179,7 @@
         @Override
         public Set<ResourceAllocation> getResourceAllocation(Link link) {
             return ImmutableSet.of(
-                    new LambdaResourceAllocation(Lambda.valueOf(77)),
+                    new LambdaResourceAllocation(LambdaResource.valueOf(77)),
                     new MplsLabelResourceAllocation(MplsLabel.valueOf(10)));
         }
 
diff --git a/core/api/src/test/java/org/onosproject/net/intent/LinkCollectionIntentTest.java b/core/api/src/test/java/org/onosproject/net/intent/LinkCollectionIntentTest.java
index 16a5e9f..988b0b4 100644
--- a/core/api/src/test/java/org/onosproject/net/intent/LinkCollectionIntentTest.java
+++ b/core/api/src/test/java/org/onosproject/net/intent/LinkCollectionIntentTest.java
@@ -26,7 +26,7 @@
 import org.onosproject.net.NetTestTools;
 import org.onosproject.net.flow.TrafficSelector;
 import org.onosproject.net.intent.constraint.LambdaConstraint;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 
 import com.google.common.collect.ImmutableSet;
 import com.google.common.testing.EqualsTester;
@@ -132,7 +132,7 @@
         final LinkedList<Constraint> constraints = new LinkedList<>();
 
         links1.add(link("src", 1, "dst", 2));
-        constraints.add(new LambdaConstraint(Lambda.valueOf(23)));
+        constraints.add(new LambdaConstraint(LambdaResource.valueOf(23)));
         final LinkCollectionIntent collectionIntent =
                 LinkCollectionIntent.builder()
                         .appId(APP_ID)
diff --git a/core/api/src/test/java/org/onosproject/net/intent/constraint/ConstraintObjectsTest.java b/core/api/src/test/java/org/onosproject/net/intent/constraint/ConstraintObjectsTest.java
index 60006a7..4e549ea 100644
--- a/core/api/src/test/java/org/onosproject/net/intent/constraint/ConstraintObjectsTest.java
+++ b/core/api/src/test/java/org/onosproject/net/intent/constraint/ConstraintObjectsTest.java
@@ -18,7 +18,7 @@
 import org.junit.Test;
 import org.onosproject.net.Link;
 import org.onosproject.net.resource.Bandwidth;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 
 import com.google.common.testing.EqualsTester;
 
@@ -65,11 +65,11 @@
     // Lambda Constraint
 
     final LambdaConstraint lambdaConstraint1 =
-            new LambdaConstraint(Lambda.valueOf(100));
+            new LambdaConstraint(LambdaResource.valueOf(100));
     final LambdaConstraint lambdaConstraintSameAs1 =
-            new LambdaConstraint(Lambda.valueOf(100));
+            new LambdaConstraint(LambdaResource.valueOf(100));
     final LambdaConstraint lambdaConstraint2 =
-            new LambdaConstraint(Lambda.valueOf(200));
+            new LambdaConstraint(LambdaResource.valueOf(200));
 
     /**
      * Checks that the objects were created properly.
diff --git a/core/common/src/test/java/org/onosproject/codec/impl/IntentCodecTest.java b/core/common/src/test/java/org/onosproject/codec/impl/IntentCodecTest.java
index afd1025..0d88b93 100644
--- a/core/common/src/test/java/org/onosproject/codec/impl/IntentCodecTest.java
+++ b/core/common/src/test/java/org/onosproject/codec/impl/IntentCodecTest.java
@@ -47,7 +47,7 @@
 import org.onosproject.net.intent.constraint.ObstacleConstraint;
 import org.onosproject.net.intent.constraint.WaypointConstraint;
 import org.onosproject.net.resource.Bandwidth;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 
 import com.fasterxml.jackson.databind.node.ObjectNode;
 import com.google.common.collect.ImmutableList;
@@ -146,7 +146,7 @@
         final List<Constraint> constraints =
                 ImmutableList.of(
                     new BandwidthConstraint(Bandwidth.bps(1.0)),
-                    new LambdaConstraint(Lambda.valueOf(3)),
+                    new LambdaConstraint(LambdaResource.valueOf(3)),
                     new AnnotationConstraint("key", 33.0),
                     new AsymmetricPathConstraint(),
                     new LatencyConstraint(Duration.ofSeconds(2)),
diff --git a/core/net/src/main/java/org/onosproject/net/intent/impl/compiler/OpticalPathIntentCompiler.java b/core/net/src/main/java/org/onosproject/net/intent/impl/compiler/OpticalPathIntentCompiler.java
index 3e193ac..e6a20f7 100644
--- a/core/net/src/main/java/org/onosproject/net/intent/impl/compiler/OpticalPathIntentCompiler.java
+++ b/core/net/src/main/java/org/onosproject/net/intent/impl/compiler/OpticalPathIntentCompiler.java
@@ -37,7 +37,7 @@
 import org.onosproject.net.intent.OpticalPathIntent;
 import org.onosproject.net.intent.impl.IntentCompilationException;
 import org.onosproject.net.resource.DefaultLinkResourceRequest;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceAllocations;
 import org.onosproject.net.resource.LinkResourceRequest;
@@ -110,7 +110,7 @@
                     .filter(x -> x.type() == ResourceType.LAMBDA)
                     .findFirst()
                     .orElseThrow(() -> new IntentCompilationException("Lambda was not assigned successfully"));
-            Lambda la = ((LambdaResourceAllocation) allocation).lambda();
+            LambdaResource la = ((LambdaResourceAllocation) allocation).lambda();
 
             TrafficTreatment.Builder treatmentBuilder = DefaultTrafficTreatment.builder();
             treatmentBuilder.setLambda((short) la.toInt());
diff --git a/core/net/src/main/java/org/onosproject/net/resource/impl/LinkResourceManager.java b/core/net/src/main/java/org/onosproject/net/resource/impl/LinkResourceManager.java
index d60dee2..ff120fe 100644
--- a/core/net/src/main/java/org/onosproject/net/resource/impl/LinkResourceManager.java
+++ b/core/net/src/main/java/org/onosproject/net/resource/impl/LinkResourceManager.java
@@ -28,7 +28,7 @@
 import org.onosproject.net.resource.BandwidthResourceAllocation;
 import org.onosproject.net.resource.BandwidthResourceRequest;
 import org.onosproject.net.resource.DefaultLinkResourceAllocations;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LambdaResourceRequest;
 import org.onosproject.net.resource.LinkResourceAllocations;
@@ -92,13 +92,13 @@
      * @param link the link
      * @return available lambdas on specified link
      */
-    private Set<Lambda> getAvailableLambdas(Link link) {
+    private Set<LambdaResource> getAvailableLambdas(Link link) {
         checkNotNull(link);
         Set<ResourceAllocation> resAllocs = store.getFreeResources(link);
         if (resAllocs == null) {
             return Collections.emptySet();
         }
-        Set<Lambda> lambdas = new HashSet<>();
+        Set<LambdaResource> lambdas = new HashSet<>();
         for (ResourceAllocation res : resAllocs) {
             if (res.type() == ResourceType.LAMBDA) {
                 lambdas.add(((LambdaResourceAllocation) res).lambda());
@@ -114,11 +114,11 @@
      * @param links the links
      * @return available lambdas on specified links
      */
-    private Iterable<Lambda> getAvailableLambdas(Iterable<Link> links) {
+    private Iterable<LambdaResource> getAvailableLambdas(Iterable<Link> links) {
         checkNotNull(links);
         Iterator<Link> i = links.iterator();
         checkArgument(i.hasNext());
-        Set<Lambda> lambdas = new HashSet<>(getAvailableLambdas(i.next()));
+        Set<LambdaResource> lambdas = new HashSet<>(getAvailableLambdas(i.next()));
         while (i.hasNext()) {
             lambdas.retainAll(getAvailableLambdas(i.next()));
         }
@@ -162,7 +162,7 @@
                 allocs.add(new BandwidthResourceAllocation(br.bandwidth()));
                 break;
             case LAMBDA:
-                Iterator<Lambda> lambdaIterator =
+                Iterator<LambdaResource> lambdaIterator =
                         getAvailableLambdas(req.links()).iterator();
                 if (lambdaIterator.hasNext()) {
                     allocs.add(new LambdaResourceAllocation(lambdaIterator.next()));
diff --git a/core/net/src/test/java/org/onosproject/net/intent/impl/compiler/PointToPointIntentCompilerTest.java b/core/net/src/test/java/org/onosproject/net/intent/impl/compiler/PointToPointIntentCompilerTest.java
index fb318e1..a890b6a 100644
--- a/core/net/src/test/java/org/onosproject/net/intent/impl/compiler/PointToPointIntentCompilerTest.java
+++ b/core/net/src/test/java/org/onosproject/net/intent/impl/compiler/PointToPointIntentCompilerTest.java
@@ -34,7 +34,7 @@
 import org.onosproject.net.intent.constraint.LambdaConstraint;
 import org.onosproject.net.intent.impl.PathNotFoundException;
 import org.onosproject.net.resource.Bandwidth;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LinkResourceService;
 
 import java.util.Arrays;
@@ -271,7 +271,7 @@
     @Test
     public void testLambdaConstrainedIntentSuccess() {
 
-        final List<Constraint> constraints = Arrays.asList(new LambdaConstraint(Lambda.valueOf(1)));
+        final List<Constraint> constraints = Arrays.asList(new LambdaConstraint(LambdaResource.valueOf(1)));
         final LinkResourceService resourceService =
                 IntentTestsMocks.MockResourceService.makeLambdaResourceService(1);
 
@@ -294,7 +294,7 @@
     @Test
     public void testLambdaConstrainedIntentFailure() {
 
-        final List<Constraint> constraints = Arrays.asList(new LambdaConstraint(Lambda.valueOf(1)));
+        final List<Constraint> constraints = Arrays.asList(new LambdaConstraint(LambdaResource.valueOf(1)));
         final LinkResourceService resourceService =
                 IntentTestsMocks.MockResourceService.makeBandwidthResourceService(10.0);
         try {
diff --git a/core/store/dist/src/main/java/org/onosproject/store/resource/impl/ConsistentLinkResourceStore.java b/core/store/dist/src/main/java/org/onosproject/store/resource/impl/ConsistentLinkResourceStore.java
index 595ade8..660440c 100644
--- a/core/store/dist/src/main/java/org/onosproject/store/resource/impl/ConsistentLinkResourceStore.java
+++ b/core/store/dist/src/main/java/org/onosproject/store/resource/impl/ConsistentLinkResourceStore.java
@@ -25,7 +25,7 @@
 import org.onosproject.net.link.LinkService;
 import org.onosproject.net.resource.Bandwidth;
 import org.onosproject.net.resource.BandwidthResourceAllocation;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceAllocations;
 import org.onosproject.net.resource.LinkResourceEvent;
@@ -138,7 +138,7 @@
         try {
             final int waves = Integer.parseInt(link.annotations().value(OPTICAL_WAVES));
             for (int i = 1; i <= waves; i++) {
-                allocations.add(new LambdaResourceAllocation(Lambda.valueOf(i)));
+                allocations.add(new LambdaResourceAllocation(LambdaResource.valueOf(i)));
             }
         } catch (NumberFormatException e) {
             log.debug("No {} annotation on link {}", OPTICAL_WAVES, link);
diff --git a/core/store/dist/src/main/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStore.java b/core/store/dist/src/main/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStore.java
index f7ff098..8eca091 100644
--- a/core/store/dist/src/main/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStore.java
+++ b/core/store/dist/src/main/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStore.java
@@ -38,7 +38,7 @@
 import org.onosproject.net.link.LinkService;
 import org.onosproject.net.resource.Bandwidth;
 import org.onosproject.net.resource.BandwidthResourceAllocation;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceAllocations;
 import org.onosproject.net.resource.LinkResourceEvent;
@@ -157,7 +157,7 @@
         try {
             final int waves = Integer.parseInt(link.annotations().value(wavesAnnotation));
             for (int i = 1; i <= waves; i++) {
-                allocations.add(new LambdaResourceAllocation(Lambda.valueOf(i)));
+                allocations.add(new LambdaResourceAllocation(LambdaResource.valueOf(i)));
             }
         } catch (NumberFormatException e) {
             log.debug("No {} annotation on link %s", wavesAnnotation, link);
diff --git a/core/store/dist/src/test/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStoreTest.java b/core/store/dist/src/test/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStoreTest.java
index cc577fe..fb32bc3 100644
--- a/core/store/dist/src/test/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStoreTest.java
+++ b/core/store/dist/src/test/java/org/onosproject/store/resource/impl/HazelcastLinkResourceStoreTest.java
@@ -33,7 +33,7 @@
 import org.onosproject.net.resource.BandwidthResourceAllocation;
 import org.onosproject.net.resource.DefaultLinkResourceAllocations;
 import org.onosproject.net.resource.DefaultLinkResourceRequest;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceAllocations;
 import org.onosproject.net.resource.LinkResourceRequest;
@@ -279,7 +279,7 @@
                         ImmutableSet.of(link))
                         .build();
         final ResourceAllocation allocation =
-                new LambdaResourceAllocation(Lambda.valueOf(33));
+                new LambdaResourceAllocation(LambdaResource.valueOf(33));
         final Set<ResourceAllocation> allocationSet = ImmutableSet.of(allocation);
 
         final LinkResourceAllocations allocations =
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java
index debdde2..b276af2 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java
@@ -152,7 +152,7 @@
 import org.onosproject.net.resource.BandwidthResourceRequest;
 import org.onosproject.net.resource.DefaultLinkResourceAllocations;
 import org.onosproject.net.resource.DefaultLinkResourceRequest;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LambdaResourceRequest;
 import org.onosproject.net.resource.LinkResourceRequest;
@@ -355,7 +355,7 @@
                     DefaultLinkResourceRequest.class,
                     BandwidthResourceRequest.class,
                     LambdaResourceRequest.class,
-                    Lambda.class,
+                    LambdaResource.class,
                     Bandwidth.class,
                     DefaultLinkResourceAllocations.class,
                     BandwidthResourceAllocation.class,
diff --git a/core/store/serializers/src/test/java/org/onosproject/store/serializers/KryoSerializerTest.java b/core/store/serializers/src/test/java/org/onosproject/store/serializers/KryoSerializerTest.java
index 19656fc..c93da2c 100644
--- a/core/store/serializers/src/test/java/org/onosproject/store/serializers/KryoSerializerTest.java
+++ b/core/store/serializers/src/test/java/org/onosproject/store/serializers/KryoSerializerTest.java
@@ -62,7 +62,7 @@
 import org.onosproject.net.resource.BandwidthResourceAllocation;
 import org.onosproject.net.resource.DefaultLinkResourceAllocations;
 import org.onosproject.net.resource.DefaultLinkResourceRequest;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceRequest;
 import org.onosproject.net.resource.ResourceAllocation;
@@ -355,7 +355,7 @@
         Map<Link, Set<ResourceAllocation>> allocations = new HashMap<>();
         allocations.put(new DefaultLink(PID, CP1, CP2, Type.DIRECT),
                         ImmutableSet.of(new BandwidthResourceAllocation(Bandwidth.bps(10.0)),
-                                        new LambdaResourceAllocation(Lambda.valueOf(1))));
+                                        new LambdaResourceAllocation(LambdaResource.valueOf(1))));
         testSerializable(new DefaultLinkResourceAllocations(request, allocations));
     }
 
@@ -367,7 +367,7 @@
 
     @Test
     public void testLambdaConstraint() {
-        testSerializable(new LambdaConstraint(Lambda.valueOf(1)));
+        testSerializable(new LambdaConstraint(LambdaResource.valueOf(1)));
     }
 
     @Test
diff --git a/core/store/trivial/src/main/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStore.java b/core/store/trivial/src/main/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStore.java
index 0d9d09c..a8f8f51 100644
--- a/core/store/trivial/src/main/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStore.java
+++ b/core/store/trivial/src/main/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStore.java
@@ -33,7 +33,7 @@
 import org.onosproject.net.intent.IntentId;
 import org.onosproject.net.resource.Bandwidth;
 import org.onosproject.net.resource.BandwidthResourceAllocation;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceAllocations;
 import org.onosproject.net.resource.LinkResourceEvent;
@@ -90,7 +90,7 @@
         try {
             int waves = Integer.parseInt(annotations.value(AnnotationKeys.OPTICAL_WAVES));
             for (int i = 1; i <= waves; i++) {
-                allocations.add(new LambdaResourceAllocation(Lambda.valueOf(i)));
+                allocations.add(new LambdaResourceAllocation(LambdaResource.valueOf(i)));
             }
         } catch (NumberFormatException e) {
             log.debug("No optical.wave annotation on link %s", link);
diff --git a/core/store/trivial/src/test/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStoreTest.java b/core/store/trivial/src/test/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStoreTest.java
index 3b281c7..5abaa6d 100644
--- a/core/store/trivial/src/test/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStoreTest.java
+++ b/core/store/trivial/src/test/java/org/onosproject/store/trivial/impl/SimpleLinkResourceStoreTest.java
@@ -32,7 +32,7 @@
 import org.onosproject.net.provider.ProviderId;
 import org.onosproject.net.resource.Bandwidth;
 import org.onosproject.net.resource.BandwidthResourceAllocation;
-import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResource;
 import org.onosproject.net.resource.LambdaResourceAllocation;
 import org.onosproject.net.resource.LinkResourceAllocations;
 import org.onosproject.net.resource.LinkResourceStore;
@@ -220,7 +220,7 @@
         @Override
         public Set<ResourceAllocation> getResourceAllocation(Link link) {
             final ResourceAllocation allocation =
-                    new LambdaResourceAllocation(Lambda.valueOf(allocatedLambda));
+                    new LambdaResourceAllocation(LambdaResource.valueOf(allocatedLambda));
             final Set<ResourceAllocation> allocations = new HashSet<>();
             allocations.add(allocation);
             return allocations;
diff --git a/core/api/src/main/java/org/onosproject/net/resource/Lambda.java b/core/api/src/main/java/org/onosproject/net/resource/LambdaResource.java
similarity index 79%
rename from core/api/src/main/java/org/onosproject/net/resource/Lambda.java
rename to core/api/src/main/java/org/onosproject/net/resource/LambdaResource.java
index 3555b12..aa14f70 100644
--- a/core/api/src/main/java/org/onosproject/net/resource/Lambda.java
+++ b/core/api/src/main/java/org/onosproject/net/resource/LambdaResource.java
@@ -20,7 +20,7 @@
 /**
  * Representation of lambda resource.
  */
-public final class Lambda extends LinkResource {
+public final class LambdaResource extends LinkResource {
 
     private final int lambda;
 
@@ -29,12 +29,12 @@
      *
      * @param lambda lambda value to be assigned
      */
-    private Lambda(int lambda) {
+    private LambdaResource(int lambda) {
         this.lambda = lambda;
     }
 
     // Constructor for serialization
-    private Lambda() {
+    private LambdaResource() {
         this.lambda = 0;
     }
 
@@ -42,10 +42,10 @@
      * Creates a new instance with given lambda.
      *
      * @param lambda lambda value to be assigned
      * @return {@link Lambda} instance with given lambda
      */
-    public static Lambda valueOf(int lambda) {
-        return new Lambda(lambda);
+    public static LambdaResource valueOf(int lambda) {
+        return new LambdaResource(lambda);
     }
 
     /**
@@ -59,8 +59,8 @@
 
     @Override
     public boolean equals(Object obj) {
-        if (obj instanceof Lambda) {
-            Lambda that = (Lambda) obj;
+        if (obj instanceof LambdaResource) {
+            LambdaResource that = (LambdaResource) obj;
             return Objects.equals(this.lambda, that.lambda);
         }
         return false;
@@ -42,10 +42,10 @@
      *
      * @param lambda lambda value to be assigned
-     * @return {@link Lambda} instance with given lambda
+     * @return {@link LambdaResource} instance with given lambda
      */